@@ -1,10 +1,9 @@
 /* 
    Project: batmon
 
-   Copyright (C) 2005-2010 GNUstep Application Project
+   Copyright (C) 2005-2014 GNUstep Application Project
 
    Author: Riccardo Mottola
-   FreeBSD support by Chris B. Vetter
 
    Created: 2005-06-25 21:06:19 +0200 by multix
    
@@ -47,8 +46,6 @@
   
   [[NSUserDefaults standardUserDefaults] registerDefaults:defaults];
   [[NSUserDefaults standardUserDefaults] synchronize];
-
-
 }
 
 - (id)init
@@ -146,6 +143,8 @@
     chargePercentToDraw = [batModel chargePercent];
     if (chargePercentToDraw > 100)
         chargePercentToDraw = 100;
+    else if (chargePercentToDraw < 0 || chargePercentToDraw == NAN)
+      chargePercentToDraw = 0;
 
     [[NSColor darkGrayColor] set];
     /* main body */
@@ -160,7 +159,9 @@
     [NSBezierPath fillRect: NSMakeRect((WIDTH/2)-2, HEIGHT+1+1, 4, 2)];
     
     /* draw the charge status */
-    if ([batModel isCritical] == YES)
+    if ([batModel isWarning] == YES)
+       [[NSColor orangeColor] set];
+    else if ([batModel isCritical] == YES)
        [[NSColor redColor] set];
     else
        [[NSColor greenColor] set];
@@ -224,7 +225,7 @@
     /* info window */
     lifeVal = [batModel lastCapacity]/[batModel designCapacity];
     [lifeGauge setDoubleValue:lifeVal*100];
-    [lifeGaugePercent setStringValue:[NSString stringWithFormat:@"%3.1f%", lifeVal*100]];
+    [lifeGaugePercent setStringValue:[NSString stringWithFormat:@"%3.1f%%", lifeVal*100]];
 
     [battType setStringValue:[batModel batteryType]];
     [manufacturer setStringValue:[batModel manufacturer]];
