@@ -1,7 +1,7 @@
 /*
    Project: batmon
 
-   Copyright (C) 2006-2013 GNUstep Application Project
+   Copyright (C) 2006-2014 GNUstep Application Project
 
    Author: Riccardo Mottola
 
@@ -22,6 +22,13 @@
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.
 */
 
+#if defined (linux)
+#define DEV_SYS_POWERSUPPLY  @"/sys/class/power_supply"
+#define DEV_PROC_PMU  @"/proc/pmu"
+#endif
+
+
+
 typedef enum
   {
     BMBStateUnknown = 0,
@@ -70,6 +77,8 @@ typedef enum
     @private float    timeRemaining;
     @private BOOL     isCharging;
     @private BOOL     isCritical;
+    @private float    critPercent;
+    @private float    warnPercent;
     @private BMBatteryStates batteryState;
   
     @private NSString *batteryType;
@@ -89,6 +98,7 @@ typedef enum
 - (float)chargePercent;
 
 - (BOOL)isCritical;
+- (BOOL)isWarning;
 - (BOOL)isCharging;
 
 - (BOOL)isUsingWattHours;
@@ -100,3 +110,9 @@ typedef enum
 @end
 
 
+@interface BatteryModel (PlatformSpecific)
+
+- (void)initPlatformSpecific;
+- (void)updatePlatformSpecific;
+
+@end
